summaryrefslogtreecommitdiffstats
path: root/source/UI/Window.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/UI/Window.h')
-rw-r--r--source/UI/Window.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/source/UI/Window.h b/source/UI/Window.h
index 0be43e819..aa7e9d0d0 100644
--- a/source/UI/Window.h
+++ b/source/UI/Window.h
@@ -120,14 +120,20 @@ public:
/// Sends the contents of the whole window to all clients of this window.
void BroadcastWholeWindow(void);
- /// Sends the progressbar to all clients of this window
- void BroadcastInventoryProgress(short a_Progressbar, short a_Value);
+ /// Sends the progressbar to all clients of this window (same as SetProperty)
+ void BroadcastProgress(int a_Progressbar, int a_Value);
// tolua_begin
const AString & GetWindowTitle() const { return m_WindowTitle; }
void SetWindowTitle(const AString & a_WindowTitle ) { m_WindowTitle = a_WindowTitle; }
+ /// Sends the UpdateWindowProperty (0x69) packet to all clients of the window
+ void SetProperty(int a_Property, int a_Value);
+
+ /// Sends the UpdateWindowPropert(0x69) packet to the specified player
+ void SetProperty(int a_Property, int a_Value, cPlayer & a_Player);
+
// tolua_end
void OwnerDestroyed(void);